A FAQ plugin for pretalx and pretix
===================================

This is a plugin for `pretix`_ and `pretalx`_, helping you create and manage a
helpful FAQ page for your attendees.
You can see an example here_.

Features: FAQ categories for helpful grouping, tags for searching, and a search
function helping attendees find the answer they're looking for quickly.

License
-------

Copyright 2018 Tobias Kunze

Released under the terms of the Apache License 2.0


.. _pretix: https://github.com/pretix/pretix
.. _pretalx: https://github.com/pretalx/pretalx
.. _pretix development setup: https://docs.pretix.eu/en/latest/development/setup.html
.. _here: https://tickets.events.ccc.de/35c3/faq/
